import * as React from "react";
import Highlighter from "react-highlight-words";
import terms from "./terms.json";
import { KeyTerm } from "./KeyTerm";

export const HighlightKeyTerms: React.FC<{ children: React.ReactNode }> = ({
  children,
}) => {
  return (
    <>
      {React.Children.map(children, (child) => {
        if (typeof child !== "string") {
          return child;
        }

        return (
          <Highlighter
            searchWords={Object.keys(terms)}
            textToHighlight={child}
            highlightTag={({ children }) => {
              const definition =
                terms[children.toLowerCase() as keyof typeof terms];

              if (!definition) {
                return null;
              }

              return <KeyTerm term={children} definition={definition} />;
            }}
          />
        );
      })}
    </>
  );
};
